@@ -2,7 +2,7 @@
 #' @exportClass enviro_par
 #
 
-#' @param .x A list to be constructed into \strong{enviro_par}.
+#' @param .x A list to be constructed into \strong{enviro_par}. If units are not provided, they will be set without conversion. If units are provided, they will be checked and converted to units that tealeaves uses.
 #' 
 #' @description 
 #' 
@@ -13,7 +13,7 @@
 enviro_par <- function(.x) {
   
   which <- "enviro"
-  nms <- parameter_names(which)
+  nms <- tealeaves::parameter_names(which)
   
   stopifnot(is.list(.x))
   
@@ -27,11 +27,6 @@ enviro_par <- function(.x) {
   
   .x %<>% magrittr::extract(nms)
   
-  .x %>%
-    purrr::map(class) %>%
-    magrittr::equals("units") %>%
-    stopifnot()
-  
   # Set units ----
   .x$P %<>% set_units(kPa)
   .x$r %<>% set_units()
@@ -48,6 +43,27 @@ enviro_par <- function(.x) {
   stopifnot(.x$T_air >= set_units(0, K))
   stopifnot(.x$wind >= set_units(0, m / s))
 
+  # T_sky can be set or provided as a function ----
+  if (is.null(.x$T_sky)) {
+    message(
+      '\ntealeaves (>= 1.0.2) will require users provide a T_sky value or function\nto calculate T_sky from other parameters.\n\nFor back-compatibility, if T_sky is not provided, this warning will appear\nand the default function used in tealeaves (< 1.0.2) will be applied.\n\nSee more details in vignette("parameter-functions")'
+    )
+    
+    .x$T_sky <- function(pars) {pars$T_air - set_units(20, K) * 
+        pars$S_sw / set_units(1000, W / m ^ 2)}
+      
+  } else {
+    
+    stopifnot(is.function(.x$T_sky) | is.double(.x$T_sky))
+    
+    if (is.double(.x$T_sky)) {
+      
+      .x$T_sky %<>% set_units(K)
+    
+    }
+    
+  }
+  
   structure(.x, class = c(stringr::str_c(which, "_par"), "list"))
   
 }
